@@ -1254,9 +1254,8 @@ class Handler(object):
     @staticmethod
     def write_to_csv(list_of_dicts,
                      outfile=None,
-                     delimiter=',',
                      append=False,
-                     header=True):
+                     delimiter=','):
 
         """
         Method to write to a csv file
@@ -1264,32 +1263,43 @@ class Handler(object):
         :param outfile: output file name
         :param delimiter: Delimiter examples : ,  ; |
         :param append: If the output should be appended to an already exising file
-        :param header: If the header should be written
         """
 
         if outfile is None:
             raise ValueError("No file name for writing")
 
-        if type(list_of_dicts).__name__ not in ('tuple', 'list'):
+        if type(list_of_dicts) not in (tuple, list):
             list_of_dicts = [list_of_dicts]
 
-        lines = list()
-        if header:
-            lines.append(delimiter.join([str(elem) for elem in list(list_of_dicts[0])]))
-
-        for data_dict in list_of_dicts:
-            lines.append(delimiter.join(list(str(val) for _, val in data_dict.items())))
-
         if append:
             if os.path.isfile(outfile):
+                with open(outfile, 'r') as f:
+                    colname_string = f.readline().strip()
+                if len(colname_string) > 0:
+                    colnames = [elem.strip() for elem in colname_string.split(delimiter)]
+                    lines = list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+                                 for elem_dict in list_of_dicts)
+                else:
+                    colnames = list(list_of_dicts[0].keys())
+                    lines = [delimiter.join(colnames)] + \
+                        list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+                             for elem_dict in list_of_dicts)
                 with open(outfile, 'a') as f:
                     for line in lines:
                         f.write(line + '\n')
             else:
+                colnames = list(list_of_dicts[0].keys())
+                lines = [delimiter.join(colnames)] + \
+                    list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+                         for elem_dict in list_of_dicts)
                 with open(outfile, 'w') as f:
                     for line in lines:
                         f.write(line + '\n')
         else:
+            colnames = list(list_of_dicts[0].keys())
+            lines = [delimiter.join(colnames)] + \
+                list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+                     for elem_dict in list_of_dicts)
             with open(outfile, 'w') as f:
                 for line in lines:
                     f.write(line + '\n')
