@@ -303,9 +303,9 @@ class Vector(object):
             if attr_def is not None:
                 for attr_name, attr_type in attr_def.items():
                     temp_attr = ogr.FieldDefn(attr_name, OGR_FIELD_DEF[attr_type])
-                    if attr_type == 'str':
+                    if attr_type in ('str', 'string'):
                         temp_attr.SetWidth(self.width)
-                    if attr_type in ('float', 'int'):
+                    if attr_type in ('float', 'int', 'integer', 'long', 'real'):
                         temp_attr.SetPrecision(self.precision)
 
                     self.layer.CreateField(temp_attr)
